import type { Meta, StoryObj } from '@storybook/react';
import Button from './Button';

const meta: Meta<typeof Button> = {
  title: 'Basic/Button',
  component: Button,
  tags: ['autodocs']
};

export default meta;

type Story = StoryObj<typeof meta>;

interface TemplateProps {
  variant: 'primary' | 'light' | 'dark';
}

const Template = ({ variant }: TemplateProps) => {
  return (
    <div style={{ color: variant === 'light' ? '#fff' : '' }}>
      <h6 className="mb-2 font-semibold">Size</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button variant={variant} size="sm">
          Small button
        </Button>
        <Button variant={variant}>Medium button</Button>
        <Button variant={variant} href="/" size="sm">
          Small Anchor
        </Button>
        <Button variant={variant} href="/">
          Medium Anchor
        </Button>
        <Button variant={variant} size="sm" outline>
          Small Outline
        </Button>
        <Button variant={variant} outline>
          Medium Outline
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Loading</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button variant={variant} size="sm" loading>
          Small button
        </Button>
        <Button variant={variant} loading>
          Medium button
        </Button>
        <Button variant={variant} href="/" size="sm" loading>
          Small Anchor
        </Button>
        <Button variant={variant} href="/" loading>
          Medium Anchor
        </Button>
        <Button variant={variant} size="sm" loading outline>
          Small Outline
        </Button>
        <Button variant={variant} loading outline>
          Medium Outline
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Disabled</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button variant={variant} size="sm" disabled>
          Small button
        </Button>
        <Button variant={variant} disabled>
          Medium button
        </Button>
        <Button variant={variant} size="sm" disabled outline>
          Small Outline
        </Button>
        <Button variant={variant} disabled outline>
          Medium Outline
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Disabled & Loading</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button variant={variant} size="sm" loading disabled>
          Small button
        </Button>
        <Button variant={variant} loading disabled>
          Medium button
        </Button>
        <Button variant={variant} size="sm" disabled loading outline>
          Small Outline
        </Button>
        <Button variant={variant} disabled loading outline>
          Medium Outline
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Multiline</h6>
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button variant={variant} size="sm">
          Lorem ipsum dolor sit <br /> amet consectetur adipisicing elit. <br />{' '}
          Quas exercitationem unde voluptate iure dolore laudantium.
        </Button>
        <Button variant={variant}>
          Lorem ipsum dolor sit amet consectetur adipisicing elit. <br /> Quas
          exercitationem unde voluptate iure dolore laudantium.
        </Button>
      </div>
      <br />
      <div className="flex gap-5 mb-4 flex-wrap items-center">
        <Button variant={variant} size="sm" loading>
          Lorem ipsum dolor sit <br /> amet consectetur adipisicing elit. <br />{' '}
          Quas exercitationem unde voluptate iure dolore laudantium.
        </Button>
        <Button variant={variant} loading>
          Lorem ipsum dolor sit amet consectetur adipisicing elit. <br /> Quas
          exercitationem unde voluptate iure dolore laudantium.
        </Button>
      </div>
      <h6 className="mb-2 font-semibold">Block</h6>
      <div className="flex flex-col gap-5">
        <Button variant={variant} size="sm" block>
          Small button
        </Button>
        <Button variant={variant} block>
          Medium button
        </Button>
        <Button variant={variant} size="sm" block loading>
          Small button
        </Button>
        <Button variant={variant} block loading>
          Medium button
        </Button>
        <Button variant={variant} size="sm" block loading disabled>
          Small button
        </Button>
        <Button variant={variant} block loading disabled>
          Medium button
        </Button>
      </div>
    </div>
  );
};

export const Primary: Story = {
  render: () => <Template variant="primary" />
};
export const Light: Story = {
  parameters: {
    backgrounds: { default: 'dark' }
  },
  render: () => <Template variant="light" />
};
export const Dark: Story = {
  render: () => <Template variant="dark" />
};
